Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(985)

Unified Diff: Source/core/inspector/AsyncCallChainMap.h

Issue 818673004: Explicitly dispose of async call chains. (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 6 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | Source/core/inspector/InspectorDebuggerAgent.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/inspector/AsyncCallChainMap.h
diff --git a/Source/core/inspector/AsyncCallChainMap.h b/Source/core/inspector/AsyncCallChainMap.h
index 0e992eae45d7ee5baf64d2ad9f34adc350560dc2..ba7e98c0bc704fa032cc1ee3dd156549f1e48efe 100644
--- a/Source/core/inspector/AsyncCallChainMap.h
+++ b/Source/core/inspector/AsyncCallChainMap.h
@@ -26,10 +26,17 @@ public:
~AsyncCallChainMap()
{
- // Verify that this object has been explicitly cleared already.
- ASSERT(!m_debuggerAgent);
+ // Verify that this object has been explicitly disposed.
+ ASSERT(hasBeenDisposed());
}
+#if ENABLE(ASSERT)
+ bool hasBeenDisposed() const
+ {
+ return !m_debuggerAgent;
+ }
+#endif
+
void dispose()
{
clear();
« no previous file with comments | « no previous file | Source/core/inspector/InspectorDebuggerAgent.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698